@@ -90,16 +90,15 @@ async def pic(setu: list, quality: int, client: AsyncClient) -> list:
     else:
         logger.info(f"图片本地不存在,正在去{setu_proxy}下载")
         content = await DownloadPic(setu_url, client)
-
-        #  此次fix结束
         if type(content) == int:
             logger.error(f"图片下载失败, 状态码: {content}")
             return [error, f"图片下载失败, 状态码: {content}", False, setu_url]
-    # 错误处理, 如果content是空bytes, 那么Image.open会报错, 跳到except, 直到change_pixel成功了, 图片应该不成问题, 可以进行保存, 并且返回pic信息
-    try:
-        image = Image.open(BytesIO(content))
-        pic = await change_pixel(image, quality)
-        # 如果有本地保存路径则存储
+        # 错误处理, 如果content是空bytes, 那么Image.open会报错, 跳到except, 直到change_pixel成功了, 图片应该不成问题,
+        try:
+            image = Image.open(BytesIO(content))
+        except Exception as e:
+            return [error, f"图片打开失败, 错误信息: {e}", False, setu_url]
+        # 保存图片, 如果save_path不为空, 以及图片不在all_file_name中, 那么就保存图片
         if save_path and not isInAllFileName:
             try:
                 with open(f"{save_path}/{file_name}", "wb") as f:
@@ -107,9 +106,11 @@ async def pic(setu: list, quality: int, client: AsyncClient) -> list:
                 all_file_name.append(file_name)
             except Exception as e:
                 logger.error(f'图片存储失败: {e}')
+    try:
+        pic = await change_pixel(image, quality)
         return [pic, data, True, setu_url]
-    except:
-        return [error, f"图片处理失败", False, setu_url]
+    except Exception as e:
+        return [error, f"图片处理失败: {e}", False, setu_url]
 
 
 # 图像镜像左右翻转
